/**
 * Copyright Zendesk, Inc.
 *
 * Use of this source code is governed under the Apache License, Version 2.0
 * found at http://www.apache.org/licenses/LICENSE-2.0.
 */

'use strict';

var containerSelection = require('@zendeskgarden/container-selection');
var React = require('react');
var PropTypes = require('prop-types');

const usePagination = options => {
  const {
    selectedItem,
    focusedItem,
    getContainerProps: getSelectionContainerProps,
    getItemProps
  } = containerSelection.useSelection(options);
  const getContainerProps = function (_temp) {
    let {
      role = 'list',
      ...other
    } = _temp === void 0 ? {} : _temp;
    return {
      ...getSelectionContainerProps(other),
      role: role === null ? undefined : role,
      'data-garden-container-id': 'containers.pagination',
      'data-garden-container-version': '1.0.6'
    };
  };
  const getPreviousPageProps = _ref => {
    let {
      role = 'listitem',
      ...other
    } = _ref;
    return {
      ...getItemProps({
        selectedAriaKey: null,
        ...other
      }),
      role: role === null ? undefined : role
    };
  };
  const getNextPageProps = _ref2 => {
    let {
      role = 'listitem',
      ...other
    } = _ref2;
    return {
      ...getItemProps({
        selectedAriaKey: null,
        ...other
      }),
      role: role === null ? undefined : role
    };
  };
  const getPageProps = _ref3 => {
    let {
      role = 'listitem',
      ...other
    } = _ref3;
    return {
      ...getItemProps({
        selectedAriaKey: 'aria-current',
        ...other
      }),
      role: role === null ? undefined : role
    };
  };
  return {
    selectedItem,
    focusedItem,
    getContainerProps,
    getPageProps,
    getPreviousPageProps,
    getNextPageProps
  };
};

const PaginationContainer = _ref => {
  let {
    children,
    render = children,
    ...options
  } = _ref;
  return React.createElement(React.Fragment, null, render(usePagination(options)));
};
PaginationContainer.propTypes = {
  children: PropTypes.func,
  render: PropTypes.func,
  focusedItem: PropTypes.any,
  selectedItem: PropTypes.any,
  onSelect: PropTypes.func,
  onFocus: PropTypes.func
};

exports.PaginationContainer = PaginationContainer;
exports.usePagination = usePagination;
